Class: SwaggerPetstore::CreateUsersWithListInputRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SwaggerPetstore::CreateUsersWithListInputRequest
- Defined in:
- lib/swagger_petstore/models/create_users_with_list_input_request.rb
Overview
CreateUsersWithListInputRequest Model.
Instance Attribute Summary collapse
-
#email ⇒ String
TODO: Write general description for this method.
-
#first_name ⇒ String
TODO: Write general description for this method.
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#last_name ⇒ String
TODO: Write general description for this method.
-
#password ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
-
#user_status ⇒ Integer
TODO: Write general description for this method.
-
#username ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id = nil, username = nil, first_name = nil, last_name = nil, email = nil, password = nil, phone = nil, user_status = nil) ⇒ CreateUsersWithListInputRequest
constructor
A new instance of CreateUsersWithListInputRequest.
Methods inherited from BaseModel
Constructor Details
#initialize(id = nil, username = nil, first_name = nil, last_name = nil, email = nil, password = nil, phone = nil, user_status = nil) ⇒ CreateUsersWithListInputRequest
Returns a new instance of CreateUsersWithListInputRequest.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 68 def initialize(id = nil, username = nil, first_name = nil, last_name = nil, email = nil, password = nil, phone = nil, user_status = nil) @id = id @username = username @first_name = first_name @last_name = last_name @email = email @password = password @phone = phone @user_status = user_status end |
Instance Attribute Details
#email ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 30 def email @email end |
#first_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 22 def first_name @first_name end |
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 14 def id @id end |
#last_name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 26 def last_name @last_name end |
#password ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 34 def password @password end |
#phone ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 38 def phone @phone end |
#user_status ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 42 def user_status @user_status end |
#username ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 18 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 87 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil username = hash.key?('username') ? hash['username'] : nil first_name = hash.key?('firstName') ? hash['firstName'] : nil last_name = hash.key?('lastName') ? hash['lastName'] : nil email = hash.key?('email') ? hash['email'] : nil password = hash.key?('password') ? hash['password'] : nil phone = hash.key?('phone') ? hash['phone'] : nil user_status = hash.key?('userStatus') ? hash['userStatus'] : nil # Create object from extracted values. CreateUsersWithListInputRequest.new(id, username, first_name, last_name, email, password, phone, user_status) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['username'] = 'username' @_hash['first_name'] = 'firstName' @_hash['last_name'] = 'lastName' @_hash['email'] = 'email' @_hash['password'] = 'password' @_hash['phone'] = 'phone' @_hash['user_status'] = 'userStatus' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 |
# File 'lib/swagger_petstore/models/create_users_with_list_input_request.rb', line 59 def self.optionals [] end |